@@ -47,7 +47,7 @@
 
 int scpi(char *ip, int port, int timeout, lxi_protocol_t protocol, char *command)
 {
-    char response[RESPONSE_LENGTH_MAX] = "";
+    char* response = malloc(RESPONSE_LENGTH_MAX);
     char command_buffer[1000];
     int device, length;;
 
@@ -105,7 +105,7 @@ int scpi(char *ip, int port, int timeout, lxi_protocol_t protocol, char *command
 
     // Disconnect
     lxi_disconnect(device);
-
+    free(response);
     return 0;
 
 error_send:
@@ -115,13 +115,13 @@ error_receive:
     lxi_disconnect(device);
 
 error_connect:
-
+    free(response);
     return 1;
 }
 
 int enter_interactive_mode(char *ip, int port, int timeout, lxi_protocol_t protocol)
 {
-    char response[RESPONSE_LENGTH_MAX] = "";
+    char* response = malloc(RESPONSE_LENGTH_MAX);
     int device, length;
     char *input = "";
 
@@ -178,88 +178,11 @@ int enter_interactive_mode(char *ip, int port, int timeout, lxi_protocol_t proto
 
     // Disconnect
     lxi_disconnect(device);
+    free(response);
 
     return 0;
 
 error_connect:
-
-    return 1;
-}
-
-int run_script(char *ip, int port, int timeout, lxi_protocol_t protocol, char *filename)
-{
-    FILE *fp;
-    char *line = NULL;
-    size_t len = 0;
-    ssize_t read;
-    char response[RESPONSE_LENGTH_MAX] = "";
-    int device, length, i;
-
-    UNUSED(protocol);
-
-    // Open script file
-    fp = fopen(filename, "r");
-    if (fp == NULL)
-    {
-        error_printf("Unable to open file %s\n", filename);
-        goto error_fopen;
-    }
-
-    // Connect
-    device = lxi_connect(ip, port, NULL, timeout, VXI11);
-    if (device != LXI_OK)
-    {
-        error_printf("Unable to connect to LXI device\n");
-        goto error_connect;
-    }
-
-    printf("Connected to %s\n", ip);
-    printf("Running script %s\n\n", filename);
-
-    while ((read = getline(&line, &len, fp)) != -1)
-    {
-        printf("%s", line);
-
-        strip_trailing_space(line);
-
-        // Skip empty lines
-        if (strlen(line) == 1)
-            continue;
-
-        // Send read line as SCPI command
-        length = lxi_send(device, line, strlen(line), timeout);
-        if (length < 0)
-            error_printf("Failed to send message\n");
-
-        // Only expect response in case we are firing a question command
-        if (line[strlen(line)-1] == '?')
-        {
-            length = lxi_receive(device, response, RESPONSE_LENGTH_MAX, timeout);
-            if (length < 0)
-            {
-                error_printf("Failed to receive message\n");
-            } else
-            {
-                // Make sure we terminate response string
-                response[length] = 0;
-
-                // Print response
-                for (i=0; i<length; i++)
-                putchar(response[i]);
-            }
-        }
-    }
-
-    free(line);
-    fclose(fp);
-
-    // Disconnect
-    lxi_disconnect(device);
-
-    return 0;
-
-error_connect:
-    fclose(fp);
-error_fopen:
+    free(response);
     return 1;
 }
