@@ -27,8 +27,8 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
  * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  */
-#ifndef SCPI_H
-#define SCPI_H
+
+#pragma once
 
 #ifdef __cplusplus
 extern "C" {
@@ -55,5 +55,3 @@ void strip_trailing_space(char *line);
 #ifdef __cplusplus
 }
 #endif
-
-#endif
